@@ -36,18 +36,37 @@ std::optional<std::string> parse_optional_string(ffi::OptionalString &&s) {
   }
 }
 
-Metadata parse_meta_data(ffi::Metadata &&meta) {
-  Metadata metadata{
-      .type = static_cast<EntryMode>(meta.mode),
-      .content_length = meta.content_length,
-      .cache_control = parse_optional_string(std::move(meta.cache_control)),
-      .content_disposition =
-          parse_optional_string(std::move(meta.content_disposition)),
-      .content_md5 = parse_optional_string(std::move(meta.content_md5)),
-      .content_type = parse_optional_string(std::move(meta.content_type)),
-      .etag = parse_optional_string(std::move(meta.etag)),
-  };
+std::optional<bool> parse_optional_bool(ffi::OptionalBool &&b) {
+  if (b.has_value) {
+    return b.value;
+  } else {
+    return std::nullopt;
+  }
+}
 
+Metadata parse_meta_data(ffi::Metadata &&meta) {
+  Metadata metadata;
+
+  // Basic information
+  metadata.type = static_cast<EntryMode>(meta.mode);
+  metadata.content_length = meta.content_length;
+
+  // HTTP-style headers
+  metadata.cache_control = parse_optional_string(std::move(meta.cache_control));
+  metadata.content_disposition =
+      parse_optional_string(std::move(meta.content_disposition));
+  metadata.content_md5 = parse_optional_string(std::move(meta.content_md5));
+  metadata.content_type = parse_optional_string(std::move(meta.content_type));
+  metadata.content_encoding =
+      parse_optional_string(std::move(meta.content_encoding));
+  metadata.etag = parse_optional_string(std::move(meta.etag));
+
+  // Versioning information
+  metadata.version = parse_optional_string(std::move(meta.version));
+  metadata.is_current = parse_optional_bool(std::move(meta.is_current));
+  metadata.is_deleted = meta.is_deleted;
+
+  // Parse last_modified timestamp
   auto last_modified_str = parse_optional_string(std::move(meta.last_modified));
   if (last_modified_str.has_value()) {
     // Parse ISO 8601 string to time_point using strptime to avoid locale lock
@@ -79,7 +98,7 @@ Metadata parse_meta_data(ffi::Metadata &&meta) {
 
 Operator::Operator() noexcept = default;
 
-void Operator::destroy() noexcept {
+void Operator::Destroy() noexcept {
   if (operator_) {
     ffi::delete_operator(operator_);
     operator_ = nullptr;
@@ -98,7 +117,7 @@ Operator::Operator(std::string_view scheme,
   operator_ = ffi::new_operator(utils::rust_str(scheme), rust_map);
 }
 
-Operator::~Operator() noexcept { destroy(); }
+Operator::~Operator() noexcept { Destroy(); }
 
 Operator::Operator(Operator &&other) noexcept : operator_(other.operator_) {
   other.operator_ = nullptr;
@@ -106,7 +125,7 @@ Operator::Operator(Operator &&other) noexcept : operator_(other.operator_) {
 
 Operator &Operator::operator=(Operator &&other) noexcept {
   if (this != &other) {
-    destroy();
+    Destroy();
 
     operator_ = other.operator_;
     other.operator_ = nullptr;
@@ -115,47 +134,48 @@ Operator &Operator::operator=(Operator &&other) noexcept {
   return *this;
 }
 
-bool Operator::available() const { return operator_ != nullptr; }
+bool Operator::Available() const { return operator_ != nullptr; }
 
 // We can't avoid copy, because std::vector hides the internal structure.
 // std::vector doesn't support init from a pointer without copy.
-std::string Operator::read(std::string_view path) {
+std::string Operator::Read(std::string_view path) {
   auto rust_vec = operator_->read(utils::rust_str(path));
   return {rust_vec.begin(), rust_vec.end()};
 }
 
-void Operator::write(std::string_view path, std::string_view data) {
-  operator_->write(utils::rust_str(path),
-                   utils::rust_slice<const uint8_t>(data));
+void Operator::Write(std::string_view path, std::string_view data) {
+  rust::Vec<uint8_t> vec;
+  std::copy(data.begin(), data.end(), std::back_inserter(vec));
+  operator_->write(utils::rust_str(path), vec);
 }
 
-bool Operator::exists(std::string_view path) {
+bool Operator::Exists(std::string_view path) {
   return operator_->exists(utils::rust_str(path));
 }
 
-bool Operator::is_exist(std::string_view path) { return exists(path); }
+bool Operator::IsExist(std::string_view path) { return Exists(path); }
 
-void Operator::create_dir(std::string_view path) {
+void Operator::CreateDir(std::string_view path) {
   operator_->create_dir(utils::rust_str(path));
 }
 
-void Operator::copy(std::string_view src, std::string_view dst) {
+void Operator::Copy(std::string_view src, std::string_view dst) {
   operator_->copy(utils::rust_str(src), utils::rust_str(dst));
 }
 
-void Operator::rename(std::string_view src, std::string_view dst) {
+void Operator::Rename(std::string_view src, std::string_view dst) {
   operator_->rename(utils::rust_str(src), utils::rust_str(dst));
 }
 
-void Operator::remove(std::string_view path) {
+void Operator::Remove(std::string_view path) {
   operator_->remove(utils::rust_str(path));
 }
 
-Metadata Operator::stat(std::string_view path) {
+Metadata Operator::Stat(std::string_view path) {
   return parse_meta_data(operator_->stat(utils::rust_str(path)));
 }
 
-std::vector<Entry> Operator::list(std::string_view path) {
+std::vector<Entry> Operator::List(std::string_view path) {
   auto rust_vec = operator_->list(utils::rust_str(path));
 
   std::vector<Entry> entries;
@@ -167,12 +187,50 @@ std::vector<Entry> Operator::list(std::string_view path) {
   return entries;
 }
 
-Lister Operator::lister(std::string_view path) {
+Lister Operator::GetLister(std::string_view path) {
   return operator_->lister(utils::rust_str(path));
 }
 
-Reader Operator::reader(std::string_view path) {
+Reader Operator::GetReader(std::string_view path) {
   return operator_->reader(utils::rust_str(path));
 }
 
 }  // namespace opendal
+opendal::Capability opendal::Operator::Info() {
+  auto op_info = operator_->info();
+  return Capability{
+      .stat = op_info.stat,
+      .stat_with_if_match = op_info.stat_with_if_match,
+      .stat_with_if_none_match = op_info.stat_with_if_none_match,
+      .read = op_info.read,
+      .read_with_if_match = op_info.read_with_if_match,
+      .read_with_if_none_match = op_info.read_with_if_none_match,
+      .read_with_override_cache_control = op_info.read_with_override_cache_control,
+      .read_with_override_content_disposition =
+          op_info.read_with_override_content_disposition,
+      .read_with_override_content_type = op_info.read_with_override_content_type,
+      .write = op_info.write,
+      .write_can_multi = op_info.write_can_multi,
+      .write_can_empty = op_info.write_can_empty,
+      .write_can_append = op_info.write_can_append,
+      .write_with_content_type = op_info.write_with_content_type,
+      .write_with_content_disposition = op_info.write_with_content_disposition,
+      .write_with_cache_control = op_info.write_with_cache_control,
+      .write_multi_max_size = op_info.write_multi_max_size,
+      .write_multi_min_size = op_info.write_multi_min_size,
+      .write_total_max_size = op_info.write_total_max_size,
+      .create_dir = op_info.create_dir,
+      .delete_feature = op_info.delete_feature,
+      .copy = op_info.copy,
+      .rename = op_info.rename,
+      .list = op_info.list,
+      .list_with_limit = op_info.list_with_limit,
+      .list_with_start_after = op_info.list_with_start_after,
+      .list_with_recursive = op_info.list_with_recursive,
+      .presign = op_info.presign,
+      .presign_read = op_info.presign_read,
+      .presign_stat = op_info.presign_stat,
+      .presign_write = op_info.presign_write,
+      .shared = op_info.shared,
+  };
+}
