@@ -17,6 +17,9 @@
 
 use std::fmt::Debug;
 use std::future::ready;
+use std::hash::Hash;
+use std::hash::Hasher;
+use std::mem;
 use std::sync::Arc;
 
 use futures::Future;
@@ -61,13 +64,8 @@ pub trait Access: Send + Sync + Debug + Unpin + 'static {
     type Writer: oio::Write;
     /// Lister is the associated lister returned in `list` operation.
     type Lister: oio::List;
-
-    /// BlockingReader is the associated reader returned `blocking_read` operation.
-    type BlockingReader: oio::BlockingRead;
-    /// BlockingWriter is the associated writer returned `blocking_write` operation.
-    type BlockingWriter: oio::BlockingWrite;
-    /// BlockingLister is the associated lister returned `blocking_list` operation.
-    type BlockingLister: oio::BlockingList;
+    /// Deleter is the associated deleter returned in `delete` operation.
+    type Deleter: oio::Delete;
 
     /// Invoke the `info` operation to get metadata of accessor.
     ///
@@ -76,7 +74,7 @@ pub trait Access: Send + Sync + Debug + Unpin + 'static {
     /// This function is required to be implemented.
     ///
     /// By returning AccessorInfo, underlying services can declare
-    /// some useful information about it self.
+    /// some useful information about itself.
     ///
     /// - scheme: declare the scheme of backend.
     /// - capabilities: declare the capabilities of current backend.
@@ -172,13 +170,7 @@ pub trait Access: Send + Sync + Debug + Unpin + 'static {
     ///
     /// - `delete` is an idempotent operation, it's safe to call `Delete` on the same path multiple times.
     /// - `delete` SHOULD return `Ok(())` if the path is deleted successfully or not exist.
-    fn delete(
-        &self,
-        path: &str,
-        args: OpDelete,
-    ) -> impl Future<Output = Result<RpDelete>> + MaybeSend {
-        let (_, _) = (path, args);
-
+    fn delete(&self) -> impl Future<Output = Result<(RpDelete, Self::Deleter)>> + MaybeSend {
         ready(Err(Error::new(
             ErrorKind::Unsupported,
             "operation is not supported",
@@ -265,134 +257,6 @@ pub trait Access: Send + Sync + Debug + Unpin + 'static {
             "operation is not supported",
         )))
     }
-
-    /// Invoke the `batch` operations.
-    ///
-    /// Require [`Capability::batch`]
-    fn batch(&self, args: OpBatch) -> impl Future<Output = Result<RpBatch>> + MaybeSend {
-        let _ = args;
-
-        ready(Err(Error::new(
-            ErrorKind::Unsupported,
-            "operation is not supported",
-        )))
-    }
-
-    /// Invoke the `blocking_create` operation on the specified path.
-    ///
-    /// This operation is the blocking version of [`Accessor::create_dir`]
-    ///
-    /// Require [`Capability::create_dir`] and [`Capability::blocking`]
-    fn blocking_create_dir(&self, path: &str, args: OpCreateDir) -> Result<RpCreateDir> {
-        let (_, _) = (path, args);
-
-        Err(Error::new(
-            ErrorKind::Unsupported,
-            "operation is not supported",
-        ))
-    }
-
-    /// Invoke the `blocking_stat` operation on the specified path.
-    ///
-    /// This operation is the blocking version of [`Accessor::stat`]
-    ///
-    /// Require [`Capability::stat`] and [`Capability::blocking`]
-    fn blocking_stat(&self, path: &str, args: OpStat) -> Result<RpStat> {
-        let (_, _) = (path, args);
-
-        Err(Error::new(
-            ErrorKind::Unsupported,
-            "operation is not supported",
-        ))
-    }
-
-    /// Invoke the `blocking_read` operation on the specified path.
-    ///
-    /// This operation is the blocking version of [`Accessor::read`]
-    ///
-    /// Require [`Capability::read`] and [`Capability::blocking`]
-    fn blocking_read(&self, path: &str, args: OpRead) -> Result<(RpRead, Self::BlockingReader)> {
-        let (_, _) = (path, args);
-
-        Err(Error::new(
-            ErrorKind::Unsupported,
-            "operation is not supported",
-        ))
-    }
-
-    /// Invoke the `blocking_write` operation on the specified path.
-    ///
-    /// This operation is the blocking version of [`Accessor::write`]
-    ///
-    /// Require [`Capability::write`] and [`Capability::blocking`]
-    fn blocking_write(&self, path: &str, args: OpWrite) -> Result<(RpWrite, Self::BlockingWriter)> {
-        let (_, _) = (path, args);
-
-        Err(Error::new(
-            ErrorKind::Unsupported,
-            "operation is not supported",
-        ))
-    }
-
-    /// Invoke the `blocking_delete` operation on the specified path.
-    ///
-    /// This operation is the blocking version of [`Accessor::delete`]
-    ///
-    /// Require [`Capability::write`] and [`Capability::blocking`]
-    fn blocking_delete(&self, path: &str, args: OpDelete) -> Result<RpDelete> {
-        let (_, _) = (path, args);
-
-        Err(Error::new(
-            ErrorKind::Unsupported,
-            "operation is not supported",
-        ))
-    }
-
-    /// Invoke the `blocking_list` operation on the specified path.
-    ///
-    /// This operation is the blocking version of [`Accessor::list`]
-    ///
-    /// Require [`Capability::list`] and [`Capability::blocking`]
-    ///
-    /// # Behavior
-    ///
-    /// - List non-exist dir should return Empty.
-    fn blocking_list(&self, path: &str, args: OpList) -> Result<(RpList, Self::BlockingLister)> {
-        let (_, _) = (path, args);
-
-        Err(Error::new(
-            ErrorKind::Unsupported,
-            "operation is not supported",
-        ))
-    }
-
-    /// Invoke the `blocking_copy` operation on the specified `from` path and `to` path.
-    ///
-    /// This operation is the blocking version of [`Accessor::copy`]
-    ///
-    /// Require [`Capability::copy`] and [`Capability::blocking`]
-    fn blocking_copy(&self, from: &str, to: &str, args: OpCopy) -> Result<RpCopy> {
-        let (_, _, _) = (from, to, args);
-
-        Err(Error::new(
-            ErrorKind::Unsupported,
-            "operation is not supported",
-        ))
-    }
-
-    /// Invoke the `blocking_rename` operation on the specified `from` path and `to` path.
-    ///
-    /// This operation is the blocking version of [`Accessor::rename`]
-    ///
-    /// Require [`Capability::rename`] and [`Capability::blocking`]
-    fn blocking_rename(&self, from: &str, to: &str, args: OpRename) -> Result<RpRename> {
-        let (_, _, _) = (from, to, args);
-
-        Err(Error::new(
-            ErrorKind::Unsupported,
-            "operation is not supported",
-        ))
-    }
 }
 
 /// `AccessDyn` is the dyn version of [`Access`] make it possible to use as
@@ -421,8 +285,7 @@ pub trait AccessDyn: Send + Sync + Debug + Unpin {
         args: OpWrite,
     ) -> BoxedFuture<'a, Result<(RpWrite, oio::Writer)>>;
     /// Dyn version of [`Accessor::delete`]
-    fn delete_dyn<'a>(&'a self, path: &'a str, args: OpDelete)
-        -> BoxedFuture<'a, Result<RpDelete>>;
+    fn delete_dyn(&self) -> BoxedFuture<'_, Result<(RpDelete, oio::Deleter)>>;
     /// Dyn version of [`Accessor::list`]
     fn list_dyn<'a>(
         &'a self,
@@ -449,40 +312,16 @@ pub trait AccessDyn: Send + Sync + Debug + Unpin {
         path: &'a str,
         args: OpPresign,
     ) -> BoxedFuture<'a, Result<RpPresign>>;
-    /// Dyn version of [`Accessor::batch`]
-    fn batch_dyn(&self, args: OpBatch) -> BoxedFuture<'_, Result<RpBatch>>;
-    /// Dyn version of [`Accessor::blocking_create_dir`]
-    fn blocking_create_dir_dyn(&self, path: &str, args: OpCreateDir) -> Result<RpCreateDir>;
-    /// Dyn version of [`Accessor::blocking_stat`]
-    fn blocking_stat_dyn(&self, path: &str, args: OpStat) -> Result<RpStat>;
-    /// Dyn version of [`Accessor::blocking_read`]
-    fn blocking_read_dyn(&self, path: &str, args: OpRead) -> Result<(RpRead, oio::BlockingReader)>;
-    /// Dyn version of [`Accessor::blocking_write`]
-    fn blocking_write_dyn(
-        &self,
-        path: &str,
-        args: OpWrite,
-    ) -> Result<(RpWrite, oio::BlockingWriter)>;
-    /// Dyn version of [`Accessor::blocking_delete`]
-    fn blocking_delete_dyn(&self, path: &str, args: OpDelete) -> Result<RpDelete>;
-    /// Dyn version of [`Accessor::blocking_list`]
-    fn blocking_list_dyn(&self, path: &str, args: OpList) -> Result<(RpList, oio::BlockingLister)>;
-    /// Dyn version of [`Accessor::blocking_copy`]
-    fn blocking_copy_dyn(&self, from: &str, to: &str, args: OpCopy) -> Result<RpCopy>;
-    /// Dyn version of [`Accessor::blocking_rename`]
-    fn blocking_rename_dyn(&self, from: &str, to: &str, args: OpRename) -> Result<RpRename>;
 }
 
 impl<A: ?Sized> AccessDyn for A
 where
     A: Access<
-        Reader = oio::Reader,
-        BlockingReader = oio::BlockingReader,
-        Writer = oio::Writer,
-        BlockingWriter = oio::BlockingWriter,
-        Lister = oio::Lister,
-        BlockingLister = oio::BlockingLister,
-    >,
+            Reader = oio::Reader,
+            Writer = oio::Writer,
+            Lister = oio::Lister,
+            Deleter = oio::Deleter,
+        >,
 {
     fn info_dyn(&self) -> Arc<AccessorInfo> {
         self.info()
@@ -516,12 +355,8 @@ where
         Box::pin(self.write(path, args))
     }
 
-    fn delete_dyn<'a>(
-        &'a self,
-        path: &'a str,
-        args: OpDelete,
-    ) -> BoxedFuture<'a, Result<RpDelete>> {
-        Box::pin(self.delete(path, args))
+    fn delete_dyn(&self) -> BoxedFuture<'_, Result<(RpDelete, oio::Deleter)>> {
+        Box::pin(self.delete())
     }
 
     fn list_dyn<'a>(
@@ -557,55 +392,13 @@ where
     ) -> BoxedFuture<'a, Result<RpPresign>> {
         Box::pin(self.presign(path, args))
     }
-
-    fn batch_dyn(&self, args: OpBatch) -> BoxedFuture<'_, Result<RpBatch>> {
-        Box::pin(self.batch(args))
-    }
-
-    fn blocking_create_dir_dyn(&self, path: &str, args: OpCreateDir) -> Result<RpCreateDir> {
-        self.blocking_create_dir(path, args)
-    }
-
-    fn blocking_stat_dyn(&self, path: &str, args: OpStat) -> Result<RpStat> {
-        self.blocking_stat(path, args)
-    }
-
-    fn blocking_read_dyn(&self, path: &str, args: OpRead) -> Result<(RpRead, oio::BlockingReader)> {
-        self.blocking_read(path, args)
-    }
-
-    fn blocking_write_dyn(
-        &self,
-        path: &str,
-        args: OpWrite,
-    ) -> Result<(RpWrite, oio::BlockingWriter)> {
-        self.blocking_write(path, args)
-    }
-
-    fn blocking_delete_dyn(&self, path: &str, args: OpDelete) -> Result<RpDelete> {
-        self.blocking_delete(path, args)
-    }
-
-    fn blocking_list_dyn(&self, path: &str, args: OpList) -> Result<(RpList, oio::BlockingLister)> {
-        self.blocking_list(path, args)
-    }
-
-    fn blocking_copy_dyn(&self, from: &str, to: &str, args: OpCopy) -> Result<RpCopy> {
-        self.blocking_copy(from, to, args)
-    }
-
-    fn blocking_rename_dyn(&self, from: &str, to: &str, args: OpRename) -> Result<RpRename> {
-        self.blocking_rename(from, to, args)
-    }
 }
 
 impl Access for dyn AccessDyn {
     type Reader = oio::Reader;
-    type BlockingReader = oio::BlockingReader;
     type Writer = oio::Writer;
-    type BlockingWriter = oio::BlockingWriter;
+    type Deleter = oio::Deleter;
     type Lister = oio::Lister;
-    type BlockingLister = oio::BlockingLister;
 
     fn info(&self) -> Arc<AccessorInfo> {
         self.info_dyn()
@@ -627,8 +420,8 @@ impl Access for dyn AccessDyn {
         self.write_dyn(path, args).await
     }
 
-    async fn delete(&self, path: &str, args: OpDelete) -> Result<RpDelete> {
-        self.delete_dyn(path, args).await
+    async fn delete(&self) -> Result<(RpDelete, Self::Deleter)> {
+        self.delete_dyn().await
     }
 
     async fn list(&self, path: &str, args: OpList) -> Result<(RpList, Self::Lister)> {
@@ -646,42 +439,6 @@ impl Access for dyn AccessDyn {
     async fn presign(&self, path: &str, args: OpPresign) -> Result<RpPresign> {
         self.presign_dyn(path, args).await
     }
-
-    fn batch(&self, args: OpBatch) -> impl Future<Output = Result<RpBatch>> + MaybeSend {
-        self.batch_dyn(args)
-    }
-
-    fn blocking_create_dir(&self, path: &str, args: OpCreateDir) -> Result<RpCreateDir> {
-        self.blocking_create_dir_dyn(path, args)
-    }
-
-    fn blocking_read(&self, path: &str, args: OpRead) -> Result<(RpRead, Self::BlockingReader)> {
-        self.blocking_read_dyn(path, args)
-    }
-
-    fn blocking_stat(&self, path: &str, args: OpStat) -> Result<RpStat> {
-        self.blocking_stat_dyn(path, args)
-    }
-
-    fn blocking_write(&self, path: &str, args: OpWrite) -> Result<(RpWrite, Self::BlockingWriter)> {
-        self.blocking_write_dyn(path, args)
-    }
-
-    fn blocking_delete(&self, path: &str, args: OpDelete) -> Result<RpDelete> {
-        self.blocking_delete_dyn(path, args)
-    }
-
-    fn blocking_list(&self, path: &str, args: OpList) -> Result<(RpList, Self::BlockingLister)> {
-        self.blocking_list_dyn(path, args)
-    }
-
-    fn blocking_copy(&self, from: &str, to: &str, args: OpCopy) -> Result<RpCopy> {
-        self.blocking_copy_dyn(from, to, args)
-    }
-
-    fn blocking_rename(&self, from: &str, to: &str, args: OpRename) -> Result<RpRename> {
-        self.blocking_rename_dyn(from, to, args)
-    }
 }
 
 /// Dummy implementation of accessor.
@@ -689,19 +446,15 @@ impl Access for () {
     type Reader = ();
     type Writer = ();
     type Lister = ();
-    type BlockingReader = ();
-    type BlockingWriter = ();
-    type BlockingLister = ();
+    type Deleter = ();
 
     fn info(&self) -> Arc<AccessorInfo> {
-        AccessorInfo {
-            scheme: Scheme::Custom("dummy"),
-            root: "".to_string(),
-            name: "dummy".to_string(),
-            native_capability: Capability::default(),
-            full_capability: Capability::default(),
-        }
-        .into()
+        let ai = AccessorInfo::default();
+        ai.set_scheme("dummy")
+            .set_root("")
+            .set_name("dummy")
+            .set_native_capability(Capability::default());
+        ai.into()
     }
 }
 
@@ -714,9 +467,7 @@ impl<T: Access + ?Sized> Access for Arc<T> {
     type Reader = T::Reader;
     type Writer = T::Writer;
     type Lister = T::Lister;
-    type BlockingReader = T::BlockingReader;
-    type BlockingWriter = T::BlockingWriter;
-    type BlockingLister = T::BlockingLister;
+    type Deleter = T::Deleter;
 
     fn info(&self) -> Arc<AccessorInfo> {
         self.as_ref().info()
@@ -750,12 +501,8 @@ impl<T: Access + ?Sized> Access for Arc<T> {
         async move { self.as_ref().write(path, args).await }
     }
 
-    fn delete(
-        &self,
-        path: &str,
-        args: OpDelete,
-    ) -> impl Future<Output = Result<RpDelete>> + MaybeSend {
-        async move { self.as_ref().delete(path, args).await }
+    fn delete(&self) -> impl Future<Output = Result<(RpDelete, Self::Deleter)>> + MaybeSend {
+        async move { self.as_ref().delete().await }
     }
 
     fn list(
@@ -791,80 +538,158 @@ impl<T: Access + ?Sized> Access for Arc<T> {
     ) -> impl Future<Output = Result<RpPresign>> + MaybeSend {
         async move { self.as_ref().presign(path, args).await }
     }
-
-    fn batch(&self, args: OpBatch) -> impl Future<Output = Result<RpBatch>> + MaybeSend {
-        async move { self.as_ref().batch(args).await }
-    }
-
-    fn blocking_create_dir(&self, path: &str, args: OpCreateDir) -> Result<RpCreateDir> {
-        self.as_ref().blocking_create_dir(path, args)
-    }
-
-    fn blocking_stat(&self, path: &str, args: OpStat) -> Result<RpStat> {
-        self.as_ref().blocking_stat(path, args)
-    }
-
-    fn blocking_read(&self, path: &str, args: OpRead) -> Result<(RpRead, Self::BlockingReader)> {
-        self.as_ref().blocking_read(path, args)
-    }
-
-    fn blocking_write(&self, path: &str, args: OpWrite) -> Result<(RpWrite, Self::BlockingWriter)> {
-        self.as_ref().blocking_write(path, args)
-    }
-
-    fn blocking_delete(&self, path: &str, args: OpDelete) -> Result<RpDelete> {
-        self.as_ref().blocking_delete(path, args)
-    }
-
-    fn blocking_list(&self, path: &str, args: OpList) -> Result<(RpList, Self::BlockingLister)> {
-        self.as_ref().blocking_list(path, args)
-    }
-
-    fn blocking_copy(&self, from: &str, to: &str, args: OpCopy) -> Result<RpCopy> {
-        self.as_ref().blocking_copy(from, to, args)
-    }
-
-    fn blocking_rename(&self, from: &str, to: &str, args: OpRename) -> Result<RpRename> {
-        self.as_ref().blocking_rename(from, to, args)
-    }
 }
 
 /// Accessor is the type erased accessor with `Arc<dyn Accessor>`.
 pub type Accessor = Arc<dyn AccessDyn>;
 
-/// Metadata for accessor, users can use this metadata to get information of underlying backend.
-#[derive(Clone, Debug, Default)]
-pub struct AccessorInfo {
-    scheme: Scheme,
-    root: String,
-    name: String,
+#[derive(Debug)]
+struct AccessorInfoInner {
+    scheme: &'static str,
+    root: Arc<str>,
+    name: Arc<str>,
 
     native_capability: Capability,
     full_capability: Capability,
+
+    http_client: HttpClient,
+    executor: Executor,
+}
+
+impl Default for AccessorInfoInner {
+    fn default() -> Self {
+        Self {
+            scheme: "unknown",
+            root: Arc::from(""),
+            name: Arc::from(""),
+            native_capability: Capability::default(),
+            full_capability: Capability::default(),
+            http_client: HttpClient::default(),
+            executor: Executor::default(),
+        }
+    }
+}
+
+/// Info for the accessor. Users can use this struct to retrieve information about the underlying backend.
+///
+/// This struct is intentionally not implemented with `Clone` to ensure that all accesses
+/// within the same operator, access layers, and services use the same instance of `AccessorInfo`.
+/// This is especially important for `HttpClient` and `Executor`.
+///
+/// ## Panic Safety
+///
+/// All methods provided by `AccessorInfo` will safely handle lock poisoning scenarios.
+/// If the inner `RwLock` is poisoned (which happens when another thread panicked while holding
+/// the write lock), this method will gracefully continue execution.
+///
+/// - For read operations, the method will return the current state.
+/// - For write operations, the method will do nothing.
+///
+/// ## Maintain Notes
+///
+/// We are using `std::sync::RwLock` to provide thread-safe access to the inner data.
+///
+/// I have performed [the bench across different arc-swap alike crates](https://github.com/krdln/arc-swap-benches):
+///
+/// ```txt
+/// test arcswap                    ... bench:          14.85 ns/iter (+/- 0.33)
+/// test arcswap_full               ... bench:         128.27 ns/iter (+/- 4.30)
+/// test baseline                   ... bench:          11.33 ns/iter (+/- 0.76)
+/// test mutex_4                    ... bench:         296.73 ns/iter (+/- 49.96)
+/// test mutex_unconteded           ... bench:          13.26 ns/iter (+/- 0.56)
+/// test rwlock_fast_4              ... bench:         201.60 ns/iter (+/- 7.47)
+/// test rwlock_fast_uncontended    ... bench:          12.77 ns/iter (+/- 0.37)
+/// test rwlock_parking_4           ... bench:         232.02 ns/iter (+/- 11.14)
+/// test rwlock_parking_uncontended ... bench:          13.18 ns/iter (+/- 0.39)
+/// test rwlock_std_4               ... bench:         219.56 ns/iter (+/- 5.56)
+/// test rwlock_std_uncontended     ... bench:          13.55 ns/iter (+/- 0.33)
+/// ```
+///
+/// The results show that as long as there aren't too many uncontended accesses, `RwLock` is the
+/// best choice, allowing for fast access and the ability to modify partial data without cloning
+/// everything.
+///
+/// And it's true: we only update and modify the internal data in a few instances, such as when
+/// building an operator or applying new layers.
+#[derive(Debug, Default)]
+pub struct AccessorInfo {
+    inner: std::sync::RwLock<AccessorInfoInner>,
+}
+
+impl PartialEq for AccessorInfo {
+    fn eq(&self, other: &Self) -> bool {
+        self.scheme() == other.scheme()
+            && self.root() == other.root()
+            && self.name() == other.name()
+    }
+}
+
+impl Eq for AccessorInfo {}
+
+impl Hash for AccessorInfo {
+    fn hash<H: Hasher>(&self, state: &mut H) {
+        self.scheme().hash(state);
+        self.root().hash(state);
+        self.name().hash(state);
+    }
 }
 
 impl AccessorInfo {
-    /// [`Scheme`] of backend.
-    pub fn scheme(&self) -> Scheme {
-        self.scheme
+    /// Scheme of backend.
+    ///
+    /// # Panic Safety
+    ///
+    /// This method safely handles lock poisoning scenarios. If the inner `RwLock` is poisoned,
+    /// this method will gracefully continue execution by simply returning the current scheme.
+    pub fn scheme(&self) -> &'static str {
+        match self.inner.read() {
+            Ok(v) => v.scheme,
+            Err(err) => err.get_ref().scheme,
+        }
     }
 
-    /// Set [`Scheme`] for backend.
-    pub fn set_scheme(&mut self, scheme: Scheme) -> &mut Self {
-        self.scheme = scheme;
+    /// Set scheme for backend.
+    ///
+    /// # Panic Safety
+    ///
+    /// This method safely handles lock poisoning scenarios. If the inner `RwLock` is poisoned,
+    /// this method will gracefully continue execution by simply skipping the update operation
+    /// rather than propagating the panic.
+    pub fn set_scheme(&self, scheme: &'static str) -> &Self {
+        if let Ok(mut v) = self.inner.write() {
+            v.scheme = scheme;
+        }
+
         self
     }
 
     /// Root of backend, will be in format like `/path/to/dir/`
-    pub fn root(&self) -> &str {
-        &self.root
+    ///
+    /// # Panic Safety
+    ///
+    /// This method safely handles lock poisoning scenarios. If the inner `RwLock` is poisoned,
+    /// this method will gracefully continue execution by simply returning the current root.
+    pub fn root(&self) -> Arc<str> {
+        match self.inner.read() {
+            Ok(v) => v.root.clone(),
+            Err(err) => err.get_ref().root.clone(),
+        }
     }
 
     /// Set root for backend.
     ///
     /// Note: input root must be normalized.
-    pub fn set_root(&mut self, root: &str) -> &mut Self {
-        self.root = root.to_string();
+    ///
+    /// # Panic Safety
+    ///
+    /// This method safely handles lock poisoning scenarios. If the inner `RwLock` is poisoned,
+    /// this method will gracefully continue execution by simply skipping the update operation
+    /// rather than propagating the panic.
+    pub fn set_root(&self, root: &str) -> &Self {
+        if let Ok(mut v) = self.inner.write() {
+            v.root = Arc::from(root);
+        }
+
         self
     }
 
@@ -872,21 +697,48 @@ impl AccessorInfo {
     ///
     /// For example:
     ///
-    /// - name for `s3` => bucket name
-    /// - name for `azblob` => container name
-    pub fn name(&self) -> &str {
-        &self.name
+    /// - `s3` => bucket name
+    /// - `azblob` => container name
+    /// - `azdfs` => filesystem name
+    /// - `azfile` => share name
+    ///
+    /// # Panic Safety
+    ///
+    /// This method safely handles lock poisoning scenarios. If the inner `RwLock` is poisoned,
+    /// this method will gracefully continue execution by simply returning the current scheme.
+    pub fn name(&self) -> Arc<str> {
+        match self.inner.read() {
+            Ok(v) => v.name.clone(),
+            Err(err) => err.get_ref().name.clone(),
+        }
     }
 
     /// Set name of this backend.
-    pub fn set_name(&mut self, name: &str) -> &mut Self {
-        self.name = name.to_string();
+    ///
+    /// # Panic Safety
+    ///
+    /// This method safely handles lock poisoning scenarios. If the inner `RwLock` is poisoned,
+    /// this method will gracefully continue execution by simply skipping the update operation
+    /// rather than propagating the panic.
+    pub fn set_name(&self, name: &str) -> &Self {
+        if let Ok(mut v) = self.inner.write() {
+            v.name = Arc::from(name)
+        }
+
         self
     }
 
     /// Get backend's native capabilities.
+    ///
+    /// # Panic Safety
+    ///
+    /// This method safely handles lock poisoning scenarios. If the inner `RwLock` is poisoned,
+    /// this method will gracefully continue execution by simply returning the current native capability.
     pub fn native_capability(&self) -> Capability {
-        self.native_capability
+        match self.inner.read() {
+            Ok(v) => v.native_capability,
+            Err(err) => err.get_ref().native_capability,
+        }
     }
 
     /// Set native capabilities for service.
@@ -894,20 +746,111 @@ impl AccessorInfo {
     /// # NOTES
     ///
     /// Set native capability will also flush the full capability. The only way to change
-    /// full_capability is via `full_capability_mut`.
-    pub fn set_native_capability(&mut self, capability: Capability) -> &mut Self {
-        self.native_capability = capability;
-        self.full_capability = capability;
+    /// full_capability is via `update_full_capability`.
+    ///
+    /// # Panic Safety
+    ///
+    /// This method safely handles lock poisoning scenarios. If the inner `RwLock` is poisoned,
+    /// this method will gracefully continue execution by simply skipping the update operation
+    /// rather than propagating the panic.
+    pub fn set_native_capability(&self, capability: Capability) -> &Self {
+        if let Ok(mut v) = self.inner.write() {
+            v.native_capability = capability;
+            v.full_capability = capability;
+        }
+
         self
     }
 
     /// Get service's full capabilities.
+    ///
+    /// # Panic Safety
+    ///
+    /// This method safely handles lock poisoning scenarios. If the inner `RwLock` is poisoned,
+    /// this method will gracefully continue execution by simply returning the current native capability.
     pub fn full_capability(&self) -> Capability {
-        self.full_capability
+        match self.inner.read() {
+            Ok(v) => v.full_capability,
+            Err(err) => err.get_ref().full_capability,
+        }
     }
 
-    /// Get service's full capabilities.
-    pub fn full_capability_mut(&mut self) -> &mut Capability {
-        &mut self.full_capability
+    /// Update service's full capabilities.
+    ///
+    /// # Panic Safety
+    ///
+    /// This method safely handles lock poisoning scenarios. If the inner `RwLock` is poisoned,
+    /// this method will gracefully continue execution by simply skipping the update operation
+    /// rather than propagating the panic.
+    pub fn update_full_capability(&self, f: impl FnOnce(Capability) -> Capability) -> &Self {
+        if let Ok(mut v) = self.inner.write() {
+            v.full_capability = f(v.full_capability);
+        }
+
+        self
+    }
+
+    /// Get http client from the context.
+    ///
+    /// # Panic Safety
+    ///
+    /// This method safely handles lock poisoning scenarios. If the inner `RwLock` is poisoned,
+    /// this method will gracefully continue execution by simply returning the current http client.
+    pub fn http_client(&self) -> HttpClient {
+        match self.inner.read() {
+            Ok(v) => v.http_client.clone(),
+            Err(err) => err.get_ref().http_client.clone(),
+        }
+    }
+
+    /// Update http client for the context.
+    ///
+    /// # Note
+    ///
+    /// Requests must be forwarded to the old HTTP client after the update. Otherwise, features such as retry, tracing, and metrics may not function properly.
+    ///
+    /// # Panic Safety
+    ///
+    /// This method safely handles lock poisoning scenarios. If the inner `RwLock` is poisoned,
+    /// this method will gracefully continue execution by simply skipping the update operation.
+    pub fn update_http_client(&self, f: impl FnOnce(HttpClient) -> HttpClient) -> &Self {
+        if let Ok(mut v) = self.inner.write() {
+            let client = mem::take(&mut v.http_client);
+            v.http_client = f(client);
+        }
+
+        self
+    }
+
+    /// Get executor from the context.
+    ///
+    /// # Panic Safety
+    ///
+    /// This method safely handles lock poisoning scenarios. If the inner `RwLock` is poisoned,
+    /// this method will gracefully continue execution by simply returning the current executor.
+    pub fn executor(&self) -> Executor {
+        match self.inner.read() {
+            Ok(v) => v.executor.clone(),
+            Err(err) => err.get_ref().executor.clone(),
+        }
+    }
+
+    /// Update executor for the context.
+    ///
+    /// # Note
+    ///
+    /// Tasks must be forwarded to the old executor after the update. Otherwise, features such as retry, timeout, and metrics may not function properly.
+    ///
+    /// # Panic Safety
+    ///
+    /// This method safely handles lock poisoning scenarios. If the inner `RwLock` is poisoned,
+    /// this method will gracefully continue execution by simply skipping the update operation.
+    pub fn update_executor(&self, f: impl FnOnce(Executor) -> Executor) -> &Self {
+        if let Ok(mut v) = self.inner.write() {
+            let executor = mem::take(&mut v.executor);
+            v.executor = f(executor);
+        }
+
+        self
     }
 }
